aboutsummaryrefslogtreecommitdiff
path: root/src/arch/ppc/boot/tables.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/ppc/boot/tables.c')
-rw-r--r--src/arch/ppc/boot/tables.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/arch/ppc/boot/tables.c b/src/arch/ppc/boot/tables.c
index 6fde37da24..a9e1e8eb0f 100644
--- a/src/arch/ppc/boot/tables.c
+++ b/src/arch/ppc/boot/tables.c
@@ -18,8 +18,8 @@ write_tables(void)
low_table_start = 0;
low_table_end = 16;
- /* The linuxbios table must be in 0-4K or 960K-1M */
- write_linuxbios_table(
+ /* The coreboot table must be in 0-4K or 960K-1M */
+ write_coreboot_table(
low_table_start, low_table_end,
rom_table_start, rom_table_end);